@@ -30,9 +30,10 @@ __ = getLazyLocalTranslate(_)
 
 
 class Locale(object):
+    # http://www.localeplanet.com/icu/
     langData = {
         'be_BY': {
-            'name': __('Belarussian'),
+            'name': 'Беларуская (Беларусь)',
             'locale': 'be_BY.UTF-8',
             'keymap': 'by',
             'dumpkeys_charset': 'koi8-u',
@@ -41,7 +42,7 @@ class Locale(object):
             'language': 'be',
         },
         'bg_BG': {
-            'name': __('Bulgarian'),
+            'name': 'Български (България)',
             'locale': 'bg_BG.UTF-8',
             'keymap': 'bg_bds-utf8',
             'dumpkeys_charset': '',
@@ -50,7 +51,7 @@ class Locale(object):
             'language': 'bg',
         },
         'fr_BE': {
-            'name': __('Belgian'),
+            'name': 'Français (Belgique)',
             'locale': 'fr_BE.UTF-8',
             'keymap': 'be-latin1',
             'dumpkeys_charset': '',
@@ -59,7 +60,7 @@ class Locale(object):
             'language': 'fr',
         },
         'pt_BR': {
-            'name': __('Brazilian Portuguese'),
+            'name': 'Português (Brasil)',
             'locale': 'pt_BR.UTF-8',
             'keymap': 'br-abnt2',
             'dumpkeys_charset': '',
@@ -68,7 +69,7 @@ class Locale(object):
             'language': 'pt_BR',
         },
         'fr_CA': {
-            'name': __('Canadian French'),
+            'name': 'Français (Canada)',
             'locale': 'fr_CA.UTF-8',
             'keymap': 'cf',
             'dumpkeys_charset': '',
@@ -77,7 +78,7 @@ class Locale(object):
             'language': 'fr',
         },
         'da_DK': {
-            'name': __('Danish'),
+            'name': 'Dansk (Danmark)',
             'locale': 'da_DK.UTF-8',
             'keymap': 'dk-latin1',
             'dumpkeys_charset': '',
@@ -86,7 +87,7 @@ class Locale(object):
             'language': 'da',
         },
         'fr_FR': {
-            'name': __('French'),
+            'name': 'Français (France)',
             'locale': 'fr_FR.UTF-8',
             'keymap': 'fr-latin9',
             'dumpkeys_charset': '',
@@ -95,7 +96,7 @@ class Locale(object):
             'language': 'fr',
         },
         'de_DE': {
-            'name': __('German'),
+            'name': 'Deutsch (Deutschland)',
             'locale': 'de_DE.UTF-8',
             'keymap': 'de-latin1',
             'dumpkeys_charset': '',
@@ -104,7 +105,7 @@ class Locale(object):
             'language': 'de',
         },
         'is_IS': {
-            'name': __('Icelandic'),
+            'name': 'Íslenska (Ísland)',
             'locale': 'is_IS.UTF-8',
             'keymap': 'is-latin1',
             'dumpkeys_charset': '',
@@ -113,7 +114,7 @@ class Locale(object):
             'language': 'is',
         },
         'it_IT': {
-            'name': __('Italian'),
+            'name': 'Italiano (Italia)',
             'locale': 'it_IT.UTF-8',
             'keymap': 'it',
             'dumpkeys_charset': '',
@@ -122,7 +123,7 @@ class Locale(object):
             'language': 'it',
         },
         'nl_NL': {
-            'name': __('Dutch'),
+            'name': 'Nederlands (Nederland)',
             'locale': 'nl_NL.UTF-8',
             'keymap': 'nl',
             'dumpkeys_charset': '',
@@ -131,7 +132,7 @@ class Locale(object):
             'language': 'nl_NL',
         },
         'nl_BE': {
-            'name': __('Belgian Dutch (Flemish)'),
+            'name': 'Nederlands (België)',
             'locale': 'nl_BE.UTF-8',
             'keymap': 'nl',
             'dumpkeys_charset': '',
@@ -140,7 +141,7 @@ class Locale(object):
             'language': 'nl_BE',
         },
         'nn_NO': {
-            'name': __('Norwegian'),
+            'name': 'Nynorsk (Noreg)',
             'locale': 'nn_NO.UTF-8',
             'keymap': 'no-latin1',
             'dumpkeys_charset': '',
@@ -149,7 +150,7 @@ class Locale(object):
             'language': 'nn',
         },
         'pl_PL': {
-            'name': __('Polish'),
+            'name': 'Polski (Polska)',
             'locale': 'pl_PL.UTF-8',
             'keymap': 'pl',
             'dumpkeys_charset': '',
@@ -158,7 +159,7 @@ class Locale(object):
             'language': 'pl',
         },
         'pt_PT': {
-            'name': __('Portuguese'),
+            'name': 'Português (Portugal)',
             'locale': 'pl_PL.UTF-8@euro',
             'keymap': 'pt-latin9',
             'dumpkeys_charset': '',
@@ -167,7 +168,7 @@ class Locale(object):
             'language': 'pt',
         },
         'ro_RO': {
-            'name': __('Romanian'),
+            'name': 'Română (România)',
             'locale': 'ro_RO.UTF-8',
             'keymap': 'ro_win',
             'dumpkeys_charset': '',
@@ -176,7 +177,7 @@ class Locale(object):
             'language': 'ro',
         },
         'ru_RU': {
-            'name': __('Russian'),
+            'name': 'Русский (Россия)',
             'locale': 'ru_RU.UTF-8',
             'keymap': '-u ruwin_cplk-UTF-8',
             'dumpkeys_charset': '',
@@ -185,7 +186,7 @@ class Locale(object):
             'language': 'ru',
         },
         'es_ES': {
-            'name': __('Spanish'),
+            'name': 'Español (España)',
             'locale': 'es_ES.UTF-8',
             'keymap': 'es euro2',
             'dumpkeys_charset': '',
@@ -194,7 +195,7 @@ class Locale(object):
             'language': 'es',
         },
         'sv_SE': {
-            'name': __('Swedish'),
+            'name': 'Svenska (Sverige)',
             'locale': 'sv_SE.UTF-8',
             'keymap': 'sv-latin1',
             'dumpkeys_charset': '',
@@ -203,7 +204,7 @@ class Locale(object):
             'language': 'sv',
         },
         'uk_UA': {
-            'name': __('Ukrainian'),
+            'name': 'Українська (Україна)',
             'locale': 'uk_UA.UTF-8',
             'keymap': 'ua-utf',
             'dumpkeys_charset': 'koi8-u',
@@ -212,7 +213,7 @@ class Locale(object):
             'language': 'ua',
         },
         'en_GB': {
-            'name': __('United Kingdom/British'),
+            'name': 'English (United Kingdom)',
             'locale': 'en_GB.UTF-8',
             'keymap': 'uk',
             'dumpkeys_charset': '',
@@ -221,7 +222,7 @@ class Locale(object):
             'language': 'en',
         },
         'en_AU': {
-            'name': __('Australian'),
+            'name': 'English (Australia)',
             'locale': 'en_AU.UTF-8',
             'keymap': 'us',
             'dumpkeys_charset': '',
@@ -230,7 +231,7 @@ class Locale(object):
             'language': 'en',
         },
         'en_US': {
-            'name': __('United States/English'),
+            'name': 'English (United States)',
             'locale': 'en_US.UTF-8',
             'keymap': 'us',
             'dumpkeys_charset': '',
@@ -362,7 +363,9 @@ class VariableOsLang(ReadonlyVariable, Locale):
     def get(self):
         return list(sorted(list(set(self.getLangs()) &
                                 {"en_US", "nl_NL", "nl_BE", "de_DE",
-                                 "es_ES",
+                                 "es_ES", "en_GB", "en_AU", "fr_BE",
+                                 "fr_CA", "is_IS", "sv_SE", "da_DK",
+                                 "nn_NO", "be_BY",
                                  "fr_FR", "it_IT", "pl_PL", "pt_BR",
                                  "uk_UA", "bg_BG", "ru_RU", "ro_RO",
                                  "pt_PT"})))
